# eric7.UI.upgrader

Script to upgrade the packages eric depends on.

This process must be performed while eric is closed. The script will upgrade the requested packages and will restart eric.

### Global Attributes

_ericPackages
_pyqtPackages

### Classes

None

### Functions

doUpgrade | Function to upgrade the given packages via pip.
main | Main entry point into the upgrader.
startEric | Function to start eric with the given arguments.

## doUpgrade

doUpgrade(packages)

Function to upgrade the given packages via pip.

packages (list of str)
  list of packages to be upgraded

Return:
  flag indicating a successful installation

Return Type:
  bool

Up

## main

main()

Main entry point into the upgrader.

Up

## startEric

startEric(args)

Function to start eric with the given arguments.

args (list of str)
  list containing the start arguments

Up